Struct diem_github_client::Client [−][src]
pub struct Client { /* fields omitted */ }Expand description
Client provides a client around the restful interface to GitHub API version 3. Learn more here: https://developer.github.com/v3
This is not intended for securely storing private data, though perhaps it could with a private repository. The tooling is intended to be used to exchange data in an authenticated fashion across multiple peers.
Implementations
Delete a file from a GitHub repository
Recursively delete all files, which as a by product will delete all folders
Retrieve a list of branches, this is effectively a status check on the repository
Retrieve the name of contents within a given directory, note, there are no such thing as empty directories in git.